pub fn parse_statement(input: &str) -> Result<Statement, ParseError>Expand description
Parse exactly one statement, swallow an optional trailing ;, and require
the token stream to end there.
pub fn parse_statement(input: &str) -> Result<Statement, ParseError>Parse exactly one statement, swallow an optional trailing ;, and require
the token stream to end there.